@@ -82,7 +82,8 @@ users_model_filter (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 
 	show = (tool->showall
 	        || (oobs_user_is_root (user) && tool->showroot)
-	        || (uid >= tool->minimum_uid && uid <= tool->maximum_uid));
+	        || (uid >= tool->minimum_uid && uid <= tool->maximum_uid)
+	        || oobs_self_config_is_user_self (OOBS_SELF_CONFIG (tool->self_config), user));
 
 	g_object_unref (user);
 
@@ -185,7 +186,13 @@ users_table_set_user (OobsUser *user, GtkTreeIter *iter)
 	face = user_settings_get_user_face (user, 48);
 	name = oobs_user_get_full_name (user);
 	login = oobs_user_get_login_name (user);
-	label = g_strdup_printf ("<big><b>%s</b>\n<span color=\'dark grey\'><i>%s</i></span></big>", name, login);
+
+	/* Work around users with empty Real name */
+	if (!name)
+		name = login;
+
+	label = g_markup_printf_escaped ("<big><b>%s</b>\n<span color=\'dark grey\'><i>%s</i></span></big>",
+	                                 name, login);
 
 	gtk_list_store_set (GTK_LIST_STORE (model), iter,
 			    COL_USER_FACE, face,
@@ -300,9 +307,10 @@ users_table_select_path (GtkTreePath *path)
 		(GTK_TREE_MODEL_SORT (sort_model), filter_path);
 
 	gtk_tree_selection_unselect_all (selection);
-	gtk_tree_selection_select_path (selection, filter_path);
+	gtk_tree_selection_select_path (selection, sort_path);
 
 	gtk_tree_path_free (filter_path);
+	gtk_tree_path_free (sort_path);
 }
 
 void
